summaryrefslogtreecommitdiff
path: root/testsuite
diff options
context:
space:
mode:
authorNiels Möller <nisse@lysator.liu.se>2020-11-30 13:44:17 +0100
committerNiels Möller <nisse@lysator.liu.se>2020-11-30 13:44:17 +0100
commitfcf38705f2c34349c011f9bb97f318bce736fdcb (patch)
treeed2051a9f39b6a636328a57506ff32c3e60d90d0 /testsuite
parent5ebf77033b05fdbad0bb612fa9c224862c6a5b7e (diff)
downloadnettle-fcf38705f2c34349c011f9bb97f318bce736fdcb.tar.gz
Delete name mangling of internal Chacha symbols
Diffstat (limited to 'testsuite')
-rw-r--r--testsuite/chacha-test.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/testsuite/chacha-test.c b/testsuite/chacha-test.c
index f51ff19f..5efe4ee2 100644
--- a/testsuite/chacha-test.c
+++ b/testsuite/chacha-test.c
@@ -193,8 +193,8 @@ _test_chacha(const struct tstring *key, const struct tstring *nonce,
}
else
{
- /* Uses the _chacha_core function to be able to test different
- numbers of rounds. */
+ /* Uses the _nettle_chacha_core function to be able to test
+ different numbers of rounds. */
uint32_t out[_CHACHA_STATE_LENGTH];
ASSERT (expected->length == CHACHA_BLOCK_SIZE);
ASSERT (nonce->length == CHACHA_NONCE_SIZE);
@@ -202,7 +202,7 @@ _test_chacha(const struct tstring *key, const struct tstring *nonce,
chacha_set_nonce(&ctx, nonce->data);
if (counter)
chacha_set_counter(&ctx, counter->data);
- _chacha_core (out, ctx.state, rounds);
+ _nettle_chacha_core (out, ctx.state, rounds);
if (!MEMEQ(CHACHA_BLOCK_SIZE, out, expected->data))
{